==> humhub-1.17.4.zip: humhub-1.17.4/protected/humhub/modules/user/messages/he/auth.php <==
<?php

return [
    'Back' => 'חזרה',
    'Confirm' => 'אשר',
    'Hello {displayName},' => 'שלום שם {displayName} ,',
    'Login' => 'לוגין',
    'Sign in' => 'התחבר',
    '<strong>Account</strong> registration' => '',
    '<strong>Change</strong> Password' => '',
    '<strong>Change</strong> your password' => '',
    '<strong>Join</strong> the network' => '',
    '<strong>Password</strong> changed!' => '',
    '<strong>Password</strong> recovery' => '',
    '<strong>Password</strong> recovery!' => '',
    '<strong>Please</strong> sign in' => '',
    '<strong>Registration</strong> successful!' => '',
    '<strong>Sign</strong> up' => '',
    '<strong>Your account</strong> has been successfully created!' => '',
    'Account' => '',
    'After activating your account by the administrator, you will receive a notification by email.' => '',
    'Change password' => '',
    'Create Account' => '',
    'Create account' => '',
    'Don\'t have an account? Join the network by entering your e-mail address.' => '',
    'Due to security reasons you are required to change your password in order to access the platform.' => '',
    'Enter security code above' => '',
    'Forgot your password?' => '',
    'Go to login page' => '',
    'Group' => '',
    'Hello {displayName}' => '',
    'If a user account associated with this email address exists, further instructions will be sent to you by email shortly.' => '',
    'If you don\'t use this link within 24 hours, it will expire.' => '',
    'If you\'re already a member, please login with your username/email and password.' => '',
    'Just enter your e-mail address. We\'ll send you recovery instructions!' => '',
    'Log out' => '',
    'New user needs approval' => '',
    'Password' => '',
    'Password recovery' => '',
    'Password reset' => '',
    'Please check your email and follow the instructions!' => '',
    'Please click on the link below to view request:' => '',
    'Please enter the letters from the image.' => '',
    'Please login with your username/email and password.' => '',
    'Please use the following link within the next day to reset your password.' => '',
    'Please wait' => '',
    'Register' => '',
    'Registration successful' => '',
    'Remember me' => '',
    'Reset Password' => '',
    'Reset password' => '',
    'To log in with your new account, click the button below.' => '',
    'User or Password incorrect.' => '',
    'Username or Email' => '',
    'Your email' => '',
    'Your password' => '',
    'Your password has been successfully changed!' => '',
    'Your password is incorrect!' => '',
    'a new user {displayName} needs approval.' => '',
    'back to home' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/user/messages/he/auth.php <==
<?php

return [
    'Back' => 'חזרה',
    'Confirm' => 'אשר',
    'Hello {displayName},' => 'שלום שם {displayName} ,',
    'Login' => 'לוגין',
    'Sign in' => 'התחבר',
    '<strong>Account</strong> registration' => '',
    '<strong>Change</strong> Password' => '',
    '<strong>Change</strong> your password' => '',
    '<strong>Join</strong> the network' => '',
    '<strong>Password</strong> changed!' => '',
    '<strong>Password</strong> recovery' => '',
    '<strong>Password</strong> recovery!' => '',
    '<strong>Please</strong> sign in' => '',
    '<strong>Registration</strong> successful!' => '',
    '<strong>Sign</strong> up' => '',
    '<strong>Your account</strong> has been successfully created!' => '',
    'Account' => '',
    'After activating your account by the administrator, you will receive a notification by email.' => '',
    'Almost there!' => '',
    'An email has been sent to {emailAddress}. Please check your inbox to complete the registration.' => '',
    'Change password' => '',
    'Create Account' => '',
    'Create account' => '',
    'Don\'t have an account? Join the network by entering your e-mail address.' => '',
    'Due to security reasons you are required to change your password in order to access the platform.' => '',
    'Forgot your password?' => '',
    'Go to login page' => '',
    'Group' => '',
    'Hello {displayName}' => '',
    'If a user account associated with this email address exists, further instructions will be sent to you by email shortly.' => '',
    'If you don\'t see the email, please check your spam folder.' => '',
    'If you don\'t use this link within 24 hours, it will expire.' => '',
    'If you\'re already a member, please login with your username/email and password.' => '',
    'Just enter your e-mail address. We\'ll send you recovery instructions!' => '',
    'Log out' => '',
    'New user needs approval' => '',
    'Password' => '',
    'Password recovery' => '',
    'Password reset' => '',
    'Please click on the link below to view request:' => '',
    'Please login with your username/email and password.' => '',
    'Please use the following link within the next day to reset your password.' => '',
    'Please wait' => '',
    'Register' => '',
    'Remember me' => '',
    'Reset Password' => '',
    'Reset password' => '',
    'To log in with your new account, click the button below.' => '',
    'User or Password incorrect.' => '',
    'Username or Email' => '',
    'Your email' => '',
    'Your password' => '',
    'Your password has been successfully changed!' => '',
    'Your password is incorrect!' => '',
    'a new user {displayName} needs approval.' => '',
];
